#define STRICT
#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <gl\gl.h>

void Draw ()
{
	//   
	glClearColor (1.0f, 1.0f, 1.0f, 1.0f);
	glClear (GL_COLOR_BUFFER_BIT);

	//  
	glLoadIdentity ();
	for (int i = 0; i < 30; i++) {
		glBegin (GL_LINE_STRIP);
		glColor3f (0.0f, 0.6f, 0.0f);
		glVertex3f ( 0.02f,  0.0f, 0.0f);
		glVertex3f ( 0.01f, 0.02f, 0.0f);
		glVertex3f (-0.01f, 0.02f, 0.0f);
		glVertex3f (-0.02f,  0.0f, 0.0f);
		glVertex3f (-0.01f,-0.02f, 0.0f);
		glVertex3f ( 0.01f,-0.02f, 0.0f);
		glVertex3f ( 0.02f,  0.0f, 0.0f);
		glEnd ();
		// 
		glRotatef (3.1f, 0.0f, 0.0f, 1.0f);
		glScalef  (1.14f, 1.14f, 0.0f);
	}

	//   
	glFinish ();
	SwapBuffers (wglGetCurrentDC ());
}

LRESULT CALLBACK WndProc (HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	switch (message) {
		case WM_CREATE:
		{
			//  OpenGL
			HDC hDC = GetDC (hWnd);
			PIXELFORMATDESCRIPTOR pfd;
			ZeroMemory (&pfd, sizeof (pfd));
			pfd.nSize = sizeof (PIXELFORMATDESCRIPTOR);
			pfd.nVersion = 1;
			pfd.dwFlags = PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL | PFD_DOUBLEBUFFER;
			pfd.iPixelType = PFD_TYPE_RGBA;
			pfd.cColorBits = 32;
			pfd.cDepthBits = 32;
			pfd.iLayerType = PFD_MAIN_PLANE;
			int i = ChoosePixelFormat (hDC, &pfd);
			SetPixelFormat (hDC, i, &pfd);
			DescribePixelFormat (hDC, i, sizeof (pfd), &pfd);
			HGLRC hGlrc = wglCreateContext (hDC);
			if (!hGlrc)
				return -1;
			wglMakeCurrent (hDC, hGlrc);
			return 0;
		}

		case WM_PAINT:
			//  
			if (GetUpdateRect (hWnd, NULL, FALSE)) {
				PAINTSTRUCT ps;
				BeginPaint (hWnd, &ps);
				//  
				Draw ();
				EndPaint (hWnd, &ps);
			}
			return 0;

		case WM_SIZE:
		{
			//  OpenGL    
			RECT rect;
			GetClientRect (hWnd, &rect);
			glViewport (rect.left, rect.top, rect.right, rect.bottom);
			break;
		}

		case WM_DESTROY:
		{
			//   OpenGL
			HGLRC hGlrc = wglGetCurrentContext ();
			if (hGlrc) {
				HDC hDC = wglGetCurrentDC ();
				wglMakeCurrent (NULL, NULL);
				ReleaseDC (hWnd, hDC);
				wglDeleteContext (hGlrc);
			}
			PostQuitMessage (0);
			return 0;
		}
	}
	return DefWindowProc(hWnd, message, wParam, lParam);
}

int APIENTRY WinMain (HINSTANCE hInstance, HINSTANCE, LPTSTR, int)
{
	//   
	WNDCLASSEX wcex;
	ZeroMemory (&wcex, sizeof (wcex));
	wcex.cbSize = sizeof (WNDCLASSEX); 
	wcex.style = CS_HREDRAW | CS_VREDRAW | CS_OWNDC;
	wcex.lpfnWndProc = WndProc;
	wcex.hInstance = hInstance;
	wcex.hIcon = LoadIcon (NULL, IDI_ASTERISK);
	wcex.hCursor = LoadCursor (NULL, IDC_CROSS);
	wcex.hbrBackground = NULL;
	wcex.lpszClassName = "lb041224";
	if (RegisterClassEx (&wcex)) {
		//  
		HWND hWnd = CreateWindowEx (WS_EX_APPWINDOW,
			wcex.lpszClassName, wcex.lpszClassName,
			WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN | WS_CLIPSIBLINGS | WS_VISIBLE,
			CW_USEDEFAULT, CW_USEDEFAULT, 500, 500,
			GetDesktopWindow (), NULL, hInstance, NULL);
		if (hWnd) {
			//  
			ShowWindow (hWnd, SW_NORMAL);
			UpdateWindow (hWnd);
			//   
			MSG msg;
			while (GetMessage (&msg, NULL, 0, 0)) {
				TranslateMessage (&msg);
				DispatchMessage (&msg);
			}
		}
	}
	return 0;
}
